summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSean Whitton <spwhitton@spwhitton.name>2020-10-22 23:30:09 -0700
committerSean Whitton <spwhitton@spwhitton.name>2020-10-22 23:30:09 -0700
commit2470ea35b8cbb968f92a6c1beacebd8a65ecf51f (patch)
tree2edb6367aa0427f8ed9fa66f39040bced1f2f779
parent5a094f9f2253e1f3da46a0e8be30fd0f2a727c02 (diff)
downloaddotfiles-2470ea35b8cbb968f92a6c1beacebd8a65ecf51f.tar.gz
iris -> melete as workstation
-rw-r--r--.config/cron/spwhitton_melete.silentflame.com (renamed from .config/cron/spwhitton_iris.silentflame.com)2
-rw-r--r--.duply/melete-spwhitton-home/conf (renamed from .duply/iris-spwhitton-home/conf)10
-rw-r--r--.duply/melete-spwhitton-home/exclude (renamed from .duply/iris-spwhitton-home/exclude)0
-rw-r--r--.emacs.d/init-org.el4
-rw-r--r--.mrconfig.in4
-rw-r--r--.ssh/config4
-rw-r--r--.ssh/host.d/spwhitton_melete.silentflame.com2
-rwxr-xr-xbin/i3-startup-once2
-rwxr-xr-xbin/locmaint2
9 files changed, 16 insertions, 14 deletions
diff --git a/.config/cron/spwhitton_iris.silentflame.com b/.config/cron/spwhitton_melete.silentflame.com
index 55c0bd01..015c1d33 100644
--- a/.config/cron/spwhitton_iris.silentflame.com
+++ b/.config/cron/spwhitton_melete.silentflame.com
@@ -1,7 +1,7 @@
PATH=$HOME/local/bin:$HOME/.local/bin:$HOME/src/dotfiles/bin:/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin
*/15 * * * * chronic doccheckin
-# iris has an SSD so we can check mail more often
+# melete has an SSD so we can check mail more often
*/5 * * * * chronic nice ionice -c 3 notmuch new
*/5 * * * * chronic nice ionice -c 3 workstation-duplicity
diff --git a/.duply/iris-spwhitton-home/conf b/.duply/melete-spwhitton-home/conf
index 8a6c5e57..15afad8d 100644
--- a/.duply/iris-spwhitton-home/conf
+++ b/.duply/melete-spwhitton-home/conf
@@ -2,15 +2,11 @@
# you'll find a fully-commented configuration file in
# ~/.duply/sample/conf
-. "$HOME/local/auth/duply/iris-spwhitton-home"
+. "$HOME/local/auth/duply/melete-spwhitton-home"
#GPG_TEST='disabled'
-# we backup iris to S3 rather than rsync.net because iris roams
-# between WiFi networks, and so we want duplicity to backup over HTTP,
-# so backups can go ahead when SSH ports are blocked
-TARGET='s3://s3.amazonaws.com/iris-spwhitton-home/'
-
+TARGET='rsync://19371@ch-s012.rsync.net/duply/melete-spwhitton-home/'
SOURCE='/'
FILENAME='.duplicity-ignore'
DUPL_PARAMS="$DUPL_PARAMS --exclude-if-present '$FILENAME'"
@@ -22,4 +18,4 @@ DUPL_PARAMS="$DUPL_PARAMS --full-if-older-than $MAX_FULLBKP_AGE "
#TEMP_DIR=/tmp
DUPL_PARAMS="$DUPL_PARAMS --asynchronous-upload "
#DUPL_PARAMS="--log-file /var/log/duplicity.log "
-DUPL_PARAMS="$DUPL_PARAMS --s3-use-new-style --s3-unencrypted-connection --s3-use-multiprocessing "
+DUPL_PARAMS="--rsync-options \"--rsh=\\\"ssh -oBatchMode=yes -oControlMaster=no -oControlPath=none -oIdentitiesOnly=yes -i $HOME/.ssh/id_19371@ch-s012.rsync.net\\\" \" "
diff --git a/.duply/iris-spwhitton-home/exclude b/.duply/melete-spwhitton-home/exclude
index c05ad005..c05ad005 100644
--- a/.duply/iris-spwhitton-home/exclude
+++ b/.duply/melete-spwhitton-home/exclude
diff --git a/.mrconfig.in b/.mrconfig.in
index 0c43a19a..8c7c5af5 100644
--- a/.mrconfig.in
+++ b/.mrconfig.in
@@ -82,13 +82,13 @@ lib =
return 1
}
workstation() {
- on swhitton@zephyr spwhitton@hephaestus spwhitton@iris
+ on swhitton@zephyr spwhitton@hephaestus spwhitton@melete
}
mine() {
workstation || on spwhitton@athena
}
# tucson() {
- # on artemis shortgeese athena hephaestus iris
+ # on artemis shortgeese athena hephaestus iris melete
# }
# --- run a command on athena in a sane environment
diff --git a/.ssh/config b/.ssh/config
index 21246f82..38bf76d8 100644
--- a/.ssh/config
+++ b/.ssh/config
@@ -108,6 +108,10 @@ Host iris.silentflame.com | iris
User spwhitton
ForwardAgent yes
+Host melete.silentflame.com | melete
+User spwhitton
+ForwardAgent yes
+
### other people's hosts
Host github
diff --git a/.ssh/host.d/spwhitton_melete.silentflame.com b/.ssh/host.d/spwhitton_melete.silentflame.com
new file mode 100644
index 00000000..02471770
--- /dev/null
+++ b/.ssh/host.d/spwhitton_melete.silentflame.com
@@ -0,0 +1,2 @@
+swhitton@artemis-2015-08-15
+user@zephyr-2018-08-09
diff --git a/bin/i3-startup-once b/bin/i3-startup-once
index 09f1afa1..6c297fe2 100755
--- a/bin/i3-startup-once
+++ b/bin/i3-startup-once
@@ -17,7 +17,7 @@
# ---- xrandr on specific hosts
# this relies on having set the video device to 'virtio' in virt-manager
-if [ "$(hostname -f)" = "develacc.iris.silentflame.com" ]; then
+if [ "$(hostname -f)" = "develacc.melete.silentflame.com" ]; then
xrandr --output Virtual-1 --mode 1366x768
fi
diff --git a/bin/locmaint b/bin/locmaint
index a3b89746..15b21286 100755
--- a/bin/locmaint
+++ b/bin/locmaint
@@ -109,7 +109,7 @@ for (getpwuid($<) . '@' . `hostname -f`) {
if (/^root@/ or /silentflame\.com$/) {
$can_root = 1;
}
- if (/@(zephyr|iris)\.silentflame\.com$/) {
+ if (/@(zephyr|melete)\.silentflame\.com$/) {
$check_for_extdrive = 1;
}
}
diff --git a/.emacs.d/init-org.el b/.emacs.d/init-org.el
index 019a9e72..61959f14 100644
--- a/.emacs.d/init-org.el
+++ b/.emacs.d/init-org.el
@@ -465,9 +465,9 @@ different occasions."
(spw/skip-when
(or
;; #1
;; iris is a laptop, but usually it's not in Sheffield
(and (or
- (string= (system-name) "iris")
+ (string= (system-name) "melete")
(string= (system-name) "hephaestus"))
(member "@Sheffield" (org-get-tags)))
;; #2
@@ -465,9 +465,9 @@ different occasions."
(or
;; #1
- ;; iris is a laptop, but usually it's not in Sheffield
+ ;; melete is a laptop, but usually it's not in Sheffield
(and (or